Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Debugf ¶
func Debugf(format string, args ...interface{})
Debugf writes a debug message to the standard logger.
func Noticef ¶
func Noticef(format string, args ...interface{})
Noticef writes a notice message to the standard logger.
func Printf ¶
func Printf(format string, args ...interface{})
Printf writes a default message to the standard logger.
Types ¶
type Logger ¶
type Logger interface {
// Debugf writes a debug message.
Debugf(string, ...interface{})
// Verbosef writes a verbose message.
Verbosef(string, ...interface{})
// Noticef writes a notice message.
Noticef(string, ...interface{})
// Warningf writes a warning message.
Warningf(string, ...interface{})
// Printf writes a default message.
Printf(string, ...interface{})
}
Logger represents a logger.
Click to show internal directories.
Click to hide internal directories.